@@ -17,6 +17,9 @@ log = getLogger(__name__)
 # stores the consumer configurations per method
 consumer_configs = WeakKeyDictionary()
 
+# delivery_mode
+PERSISTENT = 2
+
 
 class Publisher(DependencyProvider):
     '''
@@ -121,6 +124,16 @@ class ConsumerConfig(object):
         self.queue = queue
         self.requeue_on_error = requeue_on_error
 
+    def get_queue(self, service):
+        """ Base implementation for consumer config objects.
+        ``service`` is provided for sub-classes if they need to create queues
+        using information from the service object.
+
+        Args:
+            service - An instance of ``nameko.service.Service``.
+        """
+        return self.queue
+
 
 def get_consumers(Consumer, service, on_message):
     '''
@@ -135,12 +148,13 @@ def get_consumers(Consumer, service, on_message):
         A generator with each item being a Consumer instance configured
         using the ConsumerConfig defined by the consume decorator.
     '''
-    for name, consumer_method in inspect.getmembers(service, inspect.ismethod):
+    for name, consumer_method in inspect.getmembers(service.controller,
+                                                    inspect.ismethod):
         try:
             consumer_config = consumer_configs[consumer_method.im_func]
 
             consumer = Consumer(
-                queues=[consumer_config.queue],
+                queues=[consumer_config.get_queue(service)],
                 callbacks=[
                     partial(on_message, (consumer_method, consumer_config))
                 ]
